summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--oslo_messaging/_executors/impl_eventlet.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/oslo_messaging/_executors/impl_eventlet.py b/oslo_messaging/_executors/impl_eventlet.py
index f0b0783..3786eb9 100644
--- a/oslo_messaging/_executors/impl_eventlet.py
+++ b/oslo_messaging/_executors/impl_eventlet.py
@@ -28,10 +28,11 @@ class EventletExecutor(impl_pooledexecutor.PooledExecutor):
"""A message executor which integrates with eventlet.
This is an executor which polls for incoming messages from a greenthread
- and dispatches each message in its own greenthread.
+ and dispatches each message in its own greenthread powered async
+ executor.
The stop() method kills the message polling greenthread and the wait()
method waits for all message dispatch greenthreads to complete.
"""
def __init__(self, conf, listener, dispatcher):
@@ -28,10 +28,11 @@ class EventletExecutor(impl_pooledexecutor.PooledExecutor):
The stop() method kills the message polling greenthread and the wait()
- method waits for all message dispatch greenthreads to complete.
+ method waits for all executor maintained greenthreads to complete.
"""
def __init__(self, conf, listener, dispatcher):